@@ -46,6 +46,7 @@
 
 
 #include "sgf.h"
+#include "file-parser-common.h"
 #include "sgf-parser.h"
 #include "sgf-errors.h"
 #include "sgf-privates.h"
@@ -65,55 +66,11 @@
 #include <memory.h>
 #endif
 
-
-#define SGF_END			0
-
-/* SGF specification remains silent about escaping in non-text
- * properties, but `SGFC' allows escaping in them.  Function
- * next_token_in_value() provides transparent escaping.  In order to
- * avoid premature end of value parsing, escaped ']' is replaced with
- * the below character, which is never returned by next_character().
- */
-#define ESCAPED_BRACKET		'\r'
-
-
-typedef struct _BufferPositionStorage	BufferPositionStorage;
-
-struct _BufferPositionStorage {
-  char		token;
-  int		line;
-  int		column;
-  int		pending_column;
+const SgfParserParameters sgf_parser_defaults = {
+  4 * 1024 * 1024, 64 * 1024, 1024 * 1024,
+  0
 };
 
-
-#define STORE_BUFFER_POSITION(data, index, storage)			\
-  do {									\
-    (data)->stored_buffer_pointers[index] = (data)->buffer_pointer;	\
-    (storage).token			  = (data)->token;		\
-    (storage).line			  = (data)->line;		\
-    (storage).column			  = (data)->column;		\
-    (storage).pending_column		  = (data)->pending_column;	\
-  } while (0)
-
-#define RESTORE_BUFFER_POSITION(data, index, storage)			\
-  do {									\
-    (data)->buffer_pointer = (data)->stored_buffer_pointers[index];	\
-    (data)->token	   = (storage).token;				\
-    (data)->line	   = (storage).line;				\
-    (data)->column	   = (storage).column;				\
-    (data)->pending_column = (storage).pending_column;			\
-  } while (0)
-
-
-#define STORE_ERROR_POSITION(data, storage)				\
-  do {									\
-    (storage).line   = (data)->line;					\
-    (storage).column = (data)->column;					\
-    (storage).notch  = (data)->error_list->last;			\
-  } while (0)
-
-
 static int	    parse_buffer (SgfParsingData *data,
 				  SgfCollection **collection,
 				  SgfErrorList **error_list,
@@ -201,10 +158,9 @@ static void	    next_token_in_value (SgfParsingData *data);
 static void	    next_character (SgfParsingData *data);
 
 
-const SgfParserParameters sgf_parser_defaults = {
-  4 * 1024 * 1024, 64 * 1024, 1024 * 1024,
-  0
-};
+/* This keeps us from having to make global functions of the file parsing. */
+#include "ugf-parser.c"
+
 
 
 
@@ -290,7 +246,9 @@ sgf_parse_file (const char *filename, SgfCollection **collection,
 			       parameters, bytes_parsed, cancellation_flag);
       }
 
+     /* How is this a double free() ?
       utils_free (parsing_data.buffer);
+     */
     }
 
     fclose (file);
@@ -615,6 +573,16 @@ parse_root (SgfParsingData *data)
 
   if (tree->root) {
     tree->current_node = tree->root;
+    if (!data->game_info_node) {
+      SgfProperty **link;
+      data->game_info_node = tree->root;
+      if (!sgf_node_find_property (data->game_info_node, SGF_PLAYER_BLACK, &link)) {
+        *link = sgf_property_new (tree, SGF_PLAYER_BLACK, *link);
+        (*link)->value.text = utils_cprintf("Unknown");
+        *link = sgf_property_new (tree, SGF_PLAYER_WHITE, *link);
+        (*link)->value.text = utils_cprintf("Unknown");
+      }
+    }
     return 1;
   }
 
@@ -667,7 +635,7 @@ parse_node_tree (SgfParsingData *data, SgfNode *parent)
 static void
 parse_node_sequence (SgfParsingData *data, SgfNode *node)
 {
-  SgfNode *game_info_node = data->game_info_node;
+  /* SgfNode *game_info_node = data->game_info_node; */
   int num_undos = 0;
 
   while (1) {
@@ -724,7 +692,6 @@ parse_node_sequence (SgfParsingData *data, SgfNode *node)
 
   board_undo (data->board, num_undos);
 
-  data->game_info_node = game_info_node;
 }
 
 
@@ -3016,7 +2983,8 @@ insert_error_valist (SgfParsingData *data, SgfError error,
 
   if (error != SGF_WARNING_ERROR_SUPPRESSED
       && ++data->times_error_reported[error] == MAX_TIMES_TO_REPORT_ERROR) {
-    error_position->notch = error_position->notch->next;
+    if (error_position->notch)
+      error_position->notch = error_position->notch->next;
     insert_error (data, SGF_WARNING_ERROR_SUPPRESSED, error_position);
   }
 }
