@@ -29,6 +29,7 @@
 
 #include <assert.h>
 #include <math.h>
+#include <stdarg.h>
 
 #ifdef HAVE_MEMORY_H
 #include <memory.h>
@@ -230,6 +231,27 @@ sgf_utils_count_variations (const SgfGameTree *tree, int of_current_node,
 }
 
 
+SgfNode *
+sgf_utils_find_next_if_at_position (SgfGameTree *tree, int x, int y)
+{
+	SgfNode *node = NULL;
+
+	assert (tree);
+	assert (tree->current_node);
+
+	if (tree->current_node->child)
+	{
+		sgf_utils_go_down_in_tree(tree, 1);
+
+		node = tree->current_node;
+		if (node->move_point.x != x || node->move_point.y != y)
+			node = sgf_utils_find_variation_at_position(tree, x, y, SGF_NEXT, 0);
+		sgf_utils_go_up_in_tree(tree, 1);
+	}
+	return node;
+}
+
+
 SgfNode *
 sgf_utils_find_variation_at_position (SgfGameTree *tree, int x, int y,
 				      SgfDirection direction,
@@ -246,7 +268,7 @@ sgf_utils_find_variation_at_position (SgfGameTree *tree, int x, int y,
   if (direction == SGF_NEXT) {
     if (!after_current) {
       if (!node->parent)
-	return NULL;
+  	return NULL;
 
       node = node->parent->child;
     }
@@ -262,8 +284,7 @@ sgf_utils_find_variation_at_position (SgfGameTree *tree, int x, int y,
     }
 
     return node;
-  }
-  else {
+  } else {
     SgfNode *result = NULL;
     SgfNode *limit;
 
