@@ -27,7 +27,7 @@
 #include "sgf-properties.h"
 #include "board.h"
 #include "utils.h"
-#include "quarry.h"
+#include "../quarry.h"
 
 
 
@@ -45,6 +45,12 @@
  */
 #define SETUP_NODE		SPECIAL_ON_GRID_VALUE
 
+enum
+{
+	FILE_FORMAT_SGF,
+	FILE_FORMAT_UGF,
+	FILE_FORMAT_UNKNOWN
+};
 
 enum {
   SGF_MARKUP_CROSS,
@@ -832,11 +838,12 @@ int	      sgf_utils_count_variations
 		 int black_variations[BOARD_GRID_SIZE],
 		 int white_variations[BOARD_GRID_SIZE],
 		 int *other_variations);
+SgfNode *     sgf_utils_find_next_if_at_position (SgfGameTree *tree,
+                                                    int x, int y);
 SgfNode *     sgf_utils_find_variation_at_position (SgfGameTree *tree,
 						    int x, int y,
 						    SgfDirection direction,
 						    int after_current);
-
 void	      sgf_utils_switch_to_variation (SgfGameTree *tree,
 					     SgfDirection direction);
 void	      sgf_utils_switch_to_given_variation (SgfGameTree *tree,
@@ -1045,6 +1052,23 @@ int		sgf_game_tree_node_is_within_view_port (SgfGameTree *tree,
 							int *node_x,
 							int *node_y);
 
+/* ugf-parser.c */
+
+int		 ugf_parse_file (const char *filename,
+				 SgfCollection **collection,
+				 SgfErrorList **error_list,
+				 const SgfParserParameters *parameters,
+				 int *file_size, int *bytes_parsed,
+				 const int *cancellation_flag);
+int		 ugf_parse_buffer (char *buffer, int size,
+				   SgfCollection **collection,
+				   SgfErrorList **error_list,
+				   const SgfParserParameters *parameters,
+				   int *bytes_parsed,
+				   const int *cancellation_flag);
+
+
+
 
 #endif /* QUARRY_SGF_H */
 
